@@ -1,3 +1,5 @@
+package Tk::Entry; 
+
 # Converted from entry.tcl --
 #
 # This file defines the default bindings for Tk entry widgets.
@@ -6,23 +8,25 @@
 #
 # Copyright (c) 1992-1994 The Regents of the University of California.
 # Copyright (c) 1994 Sun Microsystems, Inc.
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
+
+use vars qw($VERSION);
+$VERSION = '2.014'; # $Id: //depot/Tk/Entry/Entry.pm#14$
+
 # modify it under the same terms as Perl itself, subject 
 # to additional disclaimer in license.terms due to partial
 # derivation from Tk4.0 sources.
 
-package Tk::Entry; 
 require Tk::Widget;
 require Tk::Clipboard;
-require DynaLoader;
 use AutoLoader;
 
-@ISA = qw(DynaLoader Tk::Widget); 
+@ISA = qw(Tk::Widget); 
 
 import Tk qw(Ev);
 
-Tk::Widget->Construct('Entry');
+Construct Tk::Widget 'Entry';
 
 bootstrap Tk::Entry $Tk::VERSION;
 
@@ -68,12 +72,14 @@ sub ClassInit
 {
  my ($class,$mw) = @_;
  # Standard Motif bindings:
+ $mw->bind($class,'<Escape>',['selection','clear']);
+
  $mw->bind($class,"<1>",
              sub
              {
               my $w = shift;
               my $Ev = $w->XEvent;
-              Button1($w,$Ev->x);
+              $w->Button1($Ev->x);
               $w->SelectionClear;
              });
 
@@ -85,8 +91,8 @@ sub ClassInit
               my $w = shift;
               my $Ev = $w->XEvent;
               $Tk::selectMode = "word";
-              MouseSelect($w,$Ev->x);
-              eval { $w->icursor("sel.first") }
+              $w->MouseSelect($Ev->x);
+              eval {local $SIG{__DIE__}; $w->icursor("sel.first") }
              } ) ;
  $mw->bind($class,"<Triple-1>",
              sub
@@ -94,7 +100,7 @@ sub ClassInit
               my $w = shift;
               my $Ev = $w->XEvent;
               $Tk::selectMode = "line";
-              MouseSelect($w,$Ev->x);
+              $w->MouseSelect($Ev->x);
               $w->icursor(0)
              } ) ;
  $mw->bind($class,"<Shift-1>",
@@ -111,7 +117,7 @@ sub ClassInit
               my $w = shift;
               my $Ev = $w->XEvent;
               $Tk::selectMode = "word";
-              MouseSelect($w,$Ev->x)
+              $w->MouseSelect($Ev->x)
              } ) ;
  $mw->bind($class,"<Triple-Shift-1>",
              sub
@@ -119,7 +125,7 @@ sub ClassInit
               my $w = shift;
               my $Ev = $w->XEvent;
               $Tk::selectMode = "line";
-              MouseSelect($w,$Ev->x)
+              $w->MouseSelect($Ev->x)
              } ) ;
  $mw->bind($class,"<B1-Leave>",['AutoScan',Ev("x")]);
  $mw->bind($class,"<B1-Enter>",'CancelRepeat');
@@ -240,9 +246,10 @@ sub ClassInit
               my $w = shift;
               $w->selection("range",0,"end")
              } ) ;
- $mw->bind($class,"<Control-backslash>",'SelectionClear');
+ $mw->bind($class,"<Control-backslash>",['selection','clear']);
 
  $class->clipboardKeysyms($mw,"F16","F20","F18");
+ $class->clipboardKeysyms($mw,'Control-c','Control-x','Control-v');
 
  $mw->bind($class,"<KeyPress>", ['Insert',Ev(A)]);
 
@@ -262,7 +269,7 @@ sub ClassInit
              sub
              {
               my $w = shift;
-              eval { Insert($w,$w->SelectionGet)}
+              eval {local $SIG{__DIE__}; $w->Insert($w->SelectionGet)}
              } ) ;
  # Additional emacs-like bindings:
  if (!$Tk::strictMotif)
@@ -308,17 +315,6 @@ sub ClassInit
                } ) ;
    $class->clipboardKeysyms($mw,"Meta-w","Control-w","Control-y");
    # A few additional bindings of my own.
-   $mw->bind($class,"<Control-v>",
-               sub
-               {
-                my $w = shift;
-                my $Ev = $w->XEvent;
-                eval
-                 {
-                  $w->insert("insert",$w->SelectionGet);
-                  $w->SeeInsert;
-                 }
-               } ) ;
    $mw->bind($class,"<Control-w>",
                sub
                {
@@ -355,7 +351,7 @@ sub ClassInit
                 if (!$Tk::mouseMoved)
                  {
                   eval
-                   {
+                   {local $SIG{__DIE__};
                     $w->insert("insert",$w->SelectionGet);
                     $w->SeeInsert;
                    }
@@ -464,7 +460,7 @@ sub AutoScan
   {
    return;
   }
- MouseSelect($w,$x);
+ $w->MouseSelect($x);
  $w->RepeatId($w->after(50,"AutoScan",$w,$x))
 }
 # KeySelect
@@ -506,7 +502,7 @@ sub Insert
  my $s = shift;
  return unless (defined $s && $s ne "");
  eval
-  {
+  {local $SIG{__DIE__};
    $insert = $w->index("insert");
    if ($w->index("sel.first") <= $insert && $w->index("sel.last") >= $insert)
     {
@@ -603,7 +599,12 @@ sub Transpose
  $w->SeeInsert;
 }
 
-sub deleteSelected
+sub getSelected
 {
- shift->delete("sel.first","sel.last")
+ my $w = shift;
+ return undef unless $w->selection('present');
+ my $str = $w->get;
+ my $s = $w->index('sel.first');
+ my $e = $w->index('sel.last');
+ return substr($str,$s,$e+1-$s);
 }
