@@ -1,25 +1,30 @@
-# $Id: Balloon.pm,v 1.2 1996/12/02 00:33:41 rsi Exp $
+# $Id: //depot/Tk/Tixish/Balloon.pm#10$
 #
 # The help widget that provides both "balloon" and "status bar"
 # types of help messages.
 
 package Tk::Balloon;
 
-use Tk qw(Ev);
+
+use vars qw($VERSION);
+$VERSION = '2.010'; # $Id: //depot/Tk/Tixish/Balloon.pm#10$
+
+use Tk qw(Ev Exists);
 use Carp;
 require Tk::Toplevel;
 
 Tk::Widget->Construct("Balloon");
 @Tk::Balloon::ISA = qw(Tk::Toplevel);
 
+use strict;
+
 my @balloons;
 
 sub ClassInit {
     my ($class, $mw) = @_;
-    $mw->bind("all", "<Motion>", ['Tk::Balloon::Motion', Ev('X'), Ev('Y')]);
-    $mw->bind("all", "<Leave>", ['Tk::Balloon::Motion', Ev('X'), Ev('Y')]);
-    $mw->bind("all", "<Button>", ['Tk::Balloon::ButtonDown', Ev('X'), Ev('Y'), Ev('b')]);
-    $mw->bind("all", "<ButtonRelease>", ['Tk::Balloon::ButtonUp', Ev('X'), Ev('Y'), Ev('b')]);
+    $mw->bind("all", "<Motion>", ['Tk::Balloon::Motion', Ev('X'), Ev('Y'), Ev('s')]);
+    $mw->bind("all", "<Leave>",  ['Tk::Balloon::Motion', Ev('X'), Ev('Y'), Ev('s')]);
+    $mw->bind("all", "<Button>", 'Tk::Balloon::ButtonDown');
     return $class;
 }
 
@@ -58,12 +63,13 @@ sub Populate {
     # append to global list of balloons
     push(@balloons, $w);
     $w->{"popped"} = 0;
+    $w->{"buttonDown"} = 0;
     $w->ConfigSpecs(-installcolormap => ["PASSIVE", "installColormap", "InstallColormap", 0],
 		    -initwait => ["PASSIVE", "initWait", "InitWait", 350],
 		    -state => ["PASSIVE", "state", "State", "both"],
 		    -statusbar => ["PASSIVE", "statusBar", "StatusBar", undef],
-		    -background => ["DESCENDANTS", "background", "Background", "#ffff60"],
-		    -font => [$ml, "font", "Font", "-*-helvetica-medium-r-normal-*-12-*-*-*-*-*-*"],
+		    -background => ["DESCENDANTS", "background", "Background", "#C0C080"],
+		    -font => [$ml, "font", "Font", "-*-helvetica-medium-r-normal--*-120-*-*-*-*-*-*"],
 		    -borderwidth => ["SELF", "borderWidth", "BorderWidth", 1]
 );
 
@@ -78,152 +84,94 @@ sub attach {
     $balloonmsg = $msg if (not defined $balloonmsg);
     $statusmsg = $msg if (not defined $statusmsg);
     $w->{"clients"}->{$client} = {-balloonmsg => $balloonmsg, -statusmsg => $statusmsg};
+    $client->OnDestroy([$w, 'detach', $client]);
 }
 
 # detach a client from the balloon.
-sub detach {
+sub detach 
+{
     my ($w, $client) = @_;
+    return unless Exists($w);
+    $w->Deactivate if ($w->{"clients"} == $client);
     delete $w->{"clients"}->{$client};
 }
 
 sub Motion {
-    my ($w, $x, $y) = @_;
-    my $b;
+    my ($ewin, $x, $y, $s) = @_;
+    
+    # Don't do anything if a button is down or a grab is active
+    return if ($s || $ewin->grabCurrent());
 
-    foreach $bal (@balloons) {
-	$bal->_Motion($x, $y);
+    # Find which window we are over
+    my $over = $ewin->Containing($x, $y);
+    my $w;
+
+    foreach $w (@balloons) {
+	next if (($w->cget(-state) eq "none"));	# popping up disabled
+
+	# if cursor has moved over the balloon -- ignore
+	next if ((defined $over) && $over->toplevel eq $w);
+
+	# find the client window that matches
+	my $client = $over;
+	while (defined $client) {
+	    last if (exists $w->{"clients"}->{$client});
+	    $client = $client->Parent;
+	}
+	if (defined $client) {
+	    unless ($client->IS($w->{"client"})) {  
+		$w->Deactivate;
+		$w->{"client"} = $client;
+		$w->{"delay"}  = $client->after($w->cget(-initwait), sub {$w->SwitchToClient($client);});
+	    }
+	} 
+	else {
+	    # cursor is at a position covered by a non client
+	    # pop down the balloon if it is up or scheduled.
+	    $w->Deactivate if ($w->{"popped"} || $w->{"delay"});
+	    $w->{"client"} = undef;
+	}
     }
 }
 
 sub ButtonDown {
-    my ($w, $y, $b) = @_;
-    my $bal;
-
-    foreach $bal (@balloons) {
-	$bal->_ButtonDown($x, $y, $b);
+    my ($ewin) = @_;
+    my $w;
+    foreach $w (@balloons) {
+	$w->Deactivate if ($w->{"popped"} || $w->{"delay"});
     }
 }
 
-sub ButtonUp {
-    my ($w, $x, $y, $b) = @_;
-    my $bal;
-
-    foreach $bal (@balloons) {
-	$bal->_ButtonUp($x, $y, $b);
-    }
-}
-
-sub _Motion {
-    my ($w, $x, $y) = @_;
-
-    return if (($w->cget(-state) eq "none") || 	# popping up disabled
-	       ($w->{"buttonDown"}) ||		# button is already down
-	       (defined $w->grabCurrent()));	# somebody else has screen
-
-    my $cw = $w->Containing($x, $y);
-    return if ($cw eq $w);	# cursor moved over the balloon -- ignore
-
-    # find the client window that matches
-    while (defined $cw) {
-	last if (exists $w->{"clients"}->{$cw});
-	$cw = $cw->winfo("parent");
-    }
-    if (not defined $cw) {
-	# cursor is at a position covered by a non client
-	# pop down the balloon if it is up
-	if ($w->{"popped"}) {
-	    $w->Deactivate;
-	}
-	$w->{"client"} = undef;
-	return;
-    }
-    if ($w->{"client"} ne $cw) {   # Fix undef here
-	if ($w->{"popped"}) {
-	    $w->Deactivate;
-	}
-	$w->{"client"} = $cw;
-	Tk->after($w->cget(-initwait), sub {$w->SwitchToClient($cw);});
-    }
-}
-
-sub _ButtonDown {
-    my ($w, $x, $y, $b) = @_;
-
-    # call motion binding
-    $w->Motion($x, $y);
-    $w->{"buttonDown"}++;
-
-    return if (defined $w->grabCurrent());
-
-    if ($w->{"popped"}) {
-	$w->Deactivate;
-    } else {
-	$w->{"cancel"} = 1;
-    }
-}
-
-sub _ButtonUp {
-    my ($w, $x, $y, $b) = @_;
-    $w->Motion($x, $y);
-    $w->{"buttonDown"}--;
-}
-
 # switch the balloon to a new client
 sub SwitchToClient {
     my ($w, $client) = @_;
-    return if ((not $w->winfo("exists")) &&
-	       (not $client->winfo("exists")) &&
-	       ($client ne $w->{"client"})
-	      );
-    if (defined $w->{"cancel"} && $w->{"cancel"}) {
-	$w->{"cancel"} = undef;
-	return;
-    }
-    if ($w->grabCurrent) {
-	return;
-    }
-    $w->Activate;
-}
-
-sub ClientDestroy {
-    my ($w, $client) = @_;
-    return if (!$w->winfo("exists"));
-    if ($w->{"client"} ne $client) {
-	$w->Deactivate;
-	$w->{"client"} = undef;
-	delete $w->{"clients"}->{$client};
-    }
-}
-
-sub Activate {
-    my ($w) = @_;
-    if ($w->cget(-state) =~ /both|balloon/) {
-	$w->Popup;
-    }
-    if ($w->cget(-state) =~ /both|status/) {
-	$w->SetStatus;
-    }
+    return unless Exists($w);
+    return unless Exists($client);
+    return unless $client->IS($w->{"client"});
+    return if ($w->grabCurrent);
+    my $state = $w->cget(-state);
+    $w->Popup if ($state =~ /both|balloon/);
+    $w->SetStatus if ($state =~ /both|status/);
     $w->{"popped"} = 1;
-    Tk->after(200, sub {$w->Verify;});
+    $w->{"delay"}  = $w->repeat(200, ['Verify', $w]);
 }
 
 sub Verify {
     my ($w) = @_;
-    return if ((not $w->winfo("exists")) ||
-	       (!$w->{"popped"}));
-    if ($w->grabCurrent) {
-	$w->Deactivate;
-	return;
-    }
-    Tk->after(200, sub {$w->Verify;});
+    $w->Deactivate if ($w->grabCurrent);
 }
 
 sub Deactivate {
     my ($w) = @_;
-    $w->Popdown;
-    $w->ClearStatus;
-    $w->{"popped"} = 0;
-    $w->{"cancel"} = undef;
+    my $delay = delete $w->{"delay"};
+    $delay->cancel if defined $delay;
+    if ($w->{"popped"}) {
+	$w->withdraw;
+	$w->ClearStatus;
+	$w->{"popped"} = 0;
+    } else {
+	$w->{"client"} = undef;
+    }
 }
 
 sub Popup {
@@ -232,25 +180,21 @@ sub Popup {
 	$w->colormapwindows($w->winfo("toplevel"))
     }
     my $client = $w->{"client"};
-    return if (not exists $w->{"clients"}->{$client});
+    return if ((not defined $client) ||
+	       (not exists $w->{"clients"}->{$client}));
     my $msg = $w->{"clients"}->{$client}->{-balloonmsg};
     $w->Subwidget("message")->configure(-text => $msg);
-    $w->geometry("+10000+10000");
+    $w->idletasks;
+
+    return unless Exists($w);
+    return unless Exists($client);
+
+    my $x = int($client->rootx + $client->width/2);
+    my $y = int($client->rooty + int ($client->height/1.3));
+    $w->geometry("+$x+$y");
     $w->deiconify();
     $w->raise;
     $w->update;
-
-    return if (not $w->winfo("exists"));
-    return if (not $client->winfo("exists"));
-
-    my $x = int($client->winfo("rootx") + $client->winfo("width")/2);
-    my $y = int($client->winfo("rooty") + int ($client->winfo("height")/1.3));
-    $w->geometry("+$x+$y");
-}
-
-sub Popdown {
-    my ($w) = @_;
-    $w->withdraw;
 }
 
 sub SetStatus {
@@ -258,10 +202,12 @@ sub SetStatus {
     my $s = $w->cget(-statusbar);
     if ((defined $s) && $s->winfo("exists")) {
 	my $vref = $s->cget(-textvariable);
-	return if (not exists $w->{"clients"}->{$w->{"client"}});
-	my $msg = $w->{"clients"}->{$w->{"client"}}->{-statusmsg} || '';
+	my $client = $w->{"client"};
+	return if ((not defined $client) ||
+		   (not exists $w->{"clients"}->{$client}));
+	my $msg = $w->{"clients"}->{$client}->{-statusmsg} || '';
 	if (not defined $vref) {
-	    eval $s->configure(-text => $msg);  # fix undef here
+	    eval { $s->configure(-text => $msg); };
 	} else {
 	    $$vref = $msg;
 	}
@@ -281,6 +227,12 @@ sub ClearStatus {
     }
 }
 
+sub destroy {
+    my ($w) = @_;
+    @balloons = grep($w != $_, @balloons);
+    $w->SUPER::destroy;
+}
+
 1;
 
 __END__
@@ -314,7 +266,8 @@ accepts. In addition, the following options are also recognized.
 
 Specifies the amount of time to wait without activity before
 popping up a help balloon. Specified in milliseconds. Defaults to
-350 milliseconds.
+350 milliseconds. This applies only to the popped up balloon.
+The status bar message is shown instantly.
 
 =item B<-state>
 
@@ -337,7 +290,6 @@ The B<Balloon> widget supports only two non-standard methods:
 =over 4
 
 =item B<attach(>I<widget>, I<options>B<)>
-
 Attaches the widget indicated by I<widget> to the help system. The
 options can be:
 
@@ -346,7 +298,7 @@ options can be:
 =item B<-statusmsg>
 
 The argument is the message to be shown on the status bar when the
-mouse pauses over this client. If this is not specified, but
+mouse passes over this client. If this is not specified, but
 B<-msg> is specified then the message displayed on the status bar
 is the same as the argument for B<-msg>.
 
@@ -375,11 +327,10 @@ Detaches the specified widget I<widget> from the help system.
 
 =head1 AUTHOR
 
-B<Rajappa Iyer> rsi@ziplink.net
+B<Rajappa Iyer> rsi@earthling.net
 
 This code and documentation is derived from Balloon.tcl from the
 Tix4.0 distribution by Ioi Lam. This code may be redistributed
 under the same terms as Perl.
 
 =cut
-
