@@ -1,14 +1,18 @@
+package Tk::Button;  
 # Conversion from Tk4.0 button.tcl competed.
 #
 # Copyright (c) 1992-1994 The Regents of the University of California.
 # Copyright (c) 1994 Sun Microsystems, Inc.
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
+
+use vars qw($VERSION);
+$VERSION = '2.012'; # $Id: //depot/Tk/Tk/Button.pm#12$
+
 # modify it under the same terms as Perl itself, subject 
 # to additional disclaimer in license.terms due to partial
 # derivation from Tk4.0 sources.
 
-package Tk::Button;  
 use AutoLoader;
 @ISA = qw(Tk::Widget);
 
@@ -17,7 +21,7 @@ use vars qw($buttonWindow $relief);
 
 sub Tk_cmd { \&Tk::button }
 
-Tk::Widget->Construct('Button');
+Construct Tk::Widget 'Button';
 
 sub ClassInit
 {
