@@ -1,19 +1,24 @@
+package Tk::Checkbutton;  
 # Conversion from Tk4.0 button.tcl competed.
 # Copyright (c) 1992-1994 The Regents of the University of California.
 # Copyright (c) 1994 Sun Microsystems, Inc.
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
+
+
+use vars qw($VERSION);
+$VERSION = '2.010'; # $Id: //depot/Tk/Tk/Checkbutton.pm#10$
+
 # modify it under the same terms as Perl itself, subject 
 # to additional disclaimer in license.terms due to partial
 # derivation from Tk4.0 sources.
 
-package Tk::Checkbutton;  
 use AutoLoader;
 require Tk::Button;
 
 @ISA = qw(Tk::Button);
 
-Tk::Widget->Construct('Checkbutton');
+Construct Tk::Widget 'Checkbutton';
 
 sub Tk_cmd { \&Tk::checkbutton }
 
