@@ -1,8 +1,11 @@
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::Widget;
 
+use vars qw($VERSION);
+$VERSION = '2.014'; # $Id: //depot/Tk/Tk/Clipboard.pm#14$
+
 sub clipboardSet
 {
  my $w = shift;
@@ -13,20 +16,23 @@ sub clipboardSet
 sub clipboardCopy
 {
  my $w = shift;
- if ($w->IS($w->SelectionOwner))
+ my $val = $w->getSelected;
+ if (defined $val)
   {
-   $w->clipboardSet($w->SelectionGet);
+   $w->clipboardSet('--',$val);
   }
+ return $val; 
 }
 
 sub clipboardCut
 {
  my $w = shift;
- if ($w->IS($w->SelectionOwner))
+ my $val = $w->clipboardCopy;
+ if (defined $val)
   {
-   $w->clipboardSet($w->SelectionGet);
    $w->deleteSelected;
   }
+ return $val;
 }
 
 sub clipboardGet
@@ -55,23 +61,50 @@ sub clipboardPaste
 
 sub clipboardKeysyms
 {
- my $class = shift;
+ my @class = (); 
  my $mw    = shift;
+ if (ref $mw)
+  {
+   $mw = $mw->DelegateFor('bind');
+  }
+ else
+  {
+   push(@class,$mw);
+   $mw = shift;
+  }
  if (@_)
   {
    my $copy  = shift;
-   $mw->Tk::bind($class,"<$copy>",'clipboardCopy')   if (defined $copy);
+   $mw->Tk::bind(@class,"<$copy>",'clipboardCopy')   if (defined $copy);
   }
  if (@_)
   {
    my $cut   = shift;
-   $mw->Tk::bind($class,"<$cut>",'clipboardCut')     if (defined $cut);
+   $mw->Tk::bind(@class,"<$cut>",'clipboardCut')     if (defined $cut);
   }
  if (@_)
   {
    my $paste = shift;                                                
-   $mw->Tk::bind($class,"<$paste>",'clipboardPaste') if (defined $paste);
+   $mw->Tk::bind(@class,"<$paste>",'clipboardPaste') if (defined $paste);
   }
 }
 
+# These methods work for Entry and Text
+# and can be overridden where they don't work
+
+sub deleteSelected
+{
+ my $w = shift;
+ Tk::catch { $w->delete('sel.first','sel.last') };
+}
+
+sub getSelected
+{
+ my $w   = shift;
+ my $val = Tk::catch { $w->get('sel.first','sel.last') };
+ return $val; 
+}
+
+
 1;
+__END__
