@@ -1,4 +1,4 @@
-# Copyright (c) 1995-1997 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::Frame;
@@ -12,6 +12,10 @@ use Carp;
 
 Construct Tk::Widget 'Frame';
 
+
+use vars qw($VERSION);
+$VERSION = '2.014'; # $Id: //depot/Tk/Tk/Frame.pm#14$
+
 sub Menubar;
 
 sub Tk_cmd { \&Tk::frame }
@@ -20,8 +24,12 @@ sub CreateArgs
 {
  my ($package,$parent,$args) = @_;
  my @result = $package->SUPER::CreateArgs($parent,$args);
- my $colormap = delete $args->{-colormap};                     
- push(@result, '-colormap' => $colormap) if (defined $colormap);
+ my $opt;
+ foreach $opt ('-colormap','-visual')
+  {
+   my $val = delete $args->{$opt};
+   push(@result, $opt => $val) if (defined $val);
+  }
  return @result;
 }
 
@@ -66,6 +74,11 @@ sub bind
  $cw->Delegate('bind',@args);
 }
 
+sub focus
+{my ($cw,@args) = @_;
+ $cw->Delegate('focus',@args);
+}
+
 #sub bindtags
 #{my ($cw,@args) = @_;
 # $cw->Delegate('bindtags',@args);
@@ -210,8 +223,10 @@ sub AddScrollbars
     {
      my $slice  = Tk::Frame->new($cw,Name => 'ysbslice');                                       
      my $ysb    = Tk::Scrollbar->new($slice,-orient => 'vertical', -command => [ 'yview', $w ]);
-     my $corner = Tk::Frame->new($slice,Name=>'corner','-relief' => 'raised', '-width' => 20, '-height' => 20);
-     $ysb->pack(-side => 'left', -fill => 'both');
+     my $size   = $ysb->cget('-width');
+     my $corner = Tk::Frame->new($slice,Name=>'corner','-relief' => 'raised', 
+                  '-width' => $size, '-height' => $size);
+     $ysb->pack(-side => 'left', -fill => 'y');
      $cw->Advertise("yscrollbar" => $ysb); 
      $cw->Advertise("corner" => $corner);
      $cw->Advertise("ysbslice" => $slice);
@@ -306,7 +321,9 @@ sub packscrollbars
     {
      my $anchor = $opt;
      $anchor =~ s/o//g;
-     $corner->pack(-before => $corner->{'before'}, -side => $xside, -anchor => $anchor,  -pady => 2, -fill => 'x');
+     $corner->configure(-height => $xsb->ReqHeight);
+     $corner->pack(-before => $corner->{'before'}, -side => $xside, 
+                   -anchor => $anchor, -fill => 'x');
     }
    else
     {
