@@ -1,32 +1,45 @@
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::Image;
 
 # This module does for images what Tk::Widget does for widgets:
 # provides a base class for them to inherit from.
+require DynaLoader;
 
-@Tk::Image::ISA = qw(Tk); # but are they ?
+@Tk::Image::ISA = qw(DynaLoader Tk); # but are they ?
+
+
+use vars qw($VERSION);
+$VERSION = '2.009'; # $Id: //depot/Tk/Tk/Image.pm#9$
 
 sub new
 {
  my $package = shift;
  my $widget  = shift;
+ $package->InitClass($widget);
  my $leaf = $package->Tk_image;
- my $obj = eval { $widget->image('create',$leaf,@_) };
- $widget->BackTrace($@) if ($@);
+ my $obj = $widget->image('create',$leaf,@_);
  return bless $obj,$package;
 }
 
-BEGIN 
+sub Install
 {
- my $fn;
- foreach $fn (qw(delete width height type))
-  {
-   *{"$fn"} = sub { shift->image($fn,@_) }; 
-  }
+ # Dynamically loaded image types can install standard images here
+ my ($class,$mw) = @_;
 }
 
+sub ClassInit
+{
+ # Carry out class bindings (or whatever)
+ my ($package,$mw) = @_;
+ return $package;
+}
+
+require Tk::Submethods;
+
+Direct Tk::Submethods ('image' => [qw(delete width height type)]);
+
 sub Tk::Widget::imageNames
 {
  my $w = shift;
