@@ -1,13 +1,17 @@
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Class LabeledEntry
 
 package Tk::LabEntry;
 require Tk::Frame;
+
+use vars qw($VERSION);
+$VERSION = '2.008'; # $Id: //depot/Tk/Tk/LabEntry.pm#8$
+
 @ISA = qw(Tk::Frame);
 
-Tk::Widget->Construct('LabEntry');
+Construct Tk::Widget 'LabEntry';
 
 sub Populate 
 {
