@@ -1,13 +1,17 @@
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
 package Tk::Label; 
 require Tk;
 
-@ISA = qw(Tk::Widget); 
 
-Tk::Widget->Construct('Label');
+use vars qw($VERSION);
+$VERSION = '2.008'; # $Id: //depot/Tk/Tk/Label.pm#8$
+
+@ISA = qw(Tk::Widget);
+
+Construct Tk::Widget 'Label';
 
 sub Tk_cmd { \&Tk::label }
 
