@@ -1,9 +1,13 @@
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::Menubar;
 require Tk::Frame;
 require Tk::Menubutton;
+
+use vars qw($VERSION);
+$VERSION = '2.010'; # $Id: //depot/Tk/Tk/Menubar.pm#10$
+
 @ISA = qw(Tk::Frame);
 use strict;
 
@@ -31,8 +35,10 @@ sub Menubutton
  my $name = $args{'-text'};
  my $items = delete $args{'-menuitems'};
  my %pack = ();
+ my $pack = delete $args{'-pack'};
+ %pack = @{ $pack } if defined $pack;
  my $opt;
- foreach $opt (qw(-after -before -side -padx -ipadx -pady -ipady))
+ foreach $opt (qw(-after -before -side -padx -ipadx -pady -ipady -fill))
   {
    my $val = delete $args{$opt};
    $pack{$opt} = $val if (defined $val);
