@@ -1,16 +1,25 @@
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 require Tk;
 package Tk::ROText;
 require Tk::Text;
+
+use vars qw($VERSION);
+$VERSION = '2.009'; # $Id: //depot/Tk/Tk/ROText.pm#9$
+
 @ISA = qw(Tk::Text);
-Tk::Widget->Construct('ROText');
+Construct Tk::Widget 'ROText';
 
 sub ClassInit
 {
  my ($class,$mw) = @_;
- return $class->bindRdOnly($mw);
+ my $val = $class->bindRdOnly($mw);
+ my $cb  = $mw->bind($class,'<Next>');
+ $mw->bind($class,'<space>',$cb) if (defined $cb);
+ $cb  = $mw->bind($class,'<Prior>');
+ $mw->bind($class,'<BackSpace>',$cb) if (defined $cb);
+ return $val;
 }
 
 sub Tk::Widget::ScrlROText { shift->Scrolled('ROText' => @_) }
