@@ -1,8 +1,12 @@
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::Table;
 use strict;
+
+use vars qw($VERSION);
+$VERSION = '2.009'; # $Id: //depot/Tk/Tk/Table.pm#9$
+
 use Tk::Pretty;
 use AutoLoader;
 require Tk::Frame;
@@ -48,7 +52,9 @@ sub yview
 
 sub FocusChildren
 {
- return (wantarray) ? () : 0;
+ my $t = shift;
+ return () if ($t->cget('-takefocus'));
+ return $t->SUPER::FocusChildren;
 }
                                         
 sub Populate
