@@ -1,14 +1,17 @@
-# Copyright (c) 1995-1996 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::Toplevel; 
 require Tk::Frame;
 require Tk::Wm;
-require Tk::Pretty;
 use AutoLoader;
+
+use vars qw($VERSION);
+$VERSION = '2.008'; # $Id: //depot/Tk/Tk/Toplevel.pm#8$
+
 @ISA = qw(Tk::Wm Tk::Frame);
 
-Tk::Widget->Construct('Toplevel');
+Construct Tk::Widget 'Toplevel';
 
 sub Tk_cmd { \&Tk::toplevel }
 
