@@ -1,4 +1,4 @@
-# Copyright (c) 1995-1997 Nick Ing-Simmons. All rights reserved.
+# Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 package Tk::Wm;
@@ -12,11 +12,15 @@ use strict qw(vars);
 # There are issues with this stuff now we have Tix's wm release/capture
 # as toplevel-ness is now dynamic.
 
+
+use vars qw($VERSION);
+$VERSION = '2.012'; # $Id: //depot/Tk/Tk/Wm.pm#12$
+
 use Tk::Submethods ( 'wm' => [qw(grid)] );
 
 Direct Tk::Submethods ('wm' => [qw(aspect client colormapwindows command 
                        deiconify focusmodel frame geometry group
-                       iconbitmap iconify iconmask iconname iconposition
+                       iconbitmap iconify iconmask iconname
                        iconwindow maxsize minsize overrideredirect positionfrom
                        protocol resizable saveunder sizefrom state title transient
                        withdraw)]);
@@ -45,6 +49,7 @@ sub Post
  my ($w,$X,$Y) = @_;
  $X = int($X);
  $Y = int($Y);
+ $w->positionfrom('program');
  $w->geometry("+$X+$Y");
  $w->deiconify;
  $w->raise;
@@ -84,7 +89,7 @@ sub Popup
   }
  else
   {
-   my $sc = $w->parent->toplevel;
+   my $sc = ($w->parent) ? $w->parent->toplevel : $w;
    $rx = -$sc->vrootx;
    $ry = -$sc->vrooty;
    $rw = $w->screenwidth;
@@ -95,4 +100,18 @@ sub Popup
  $w->Post($X,$Y);
 }
 
+sub FullScreen
+{
+ my $w = shift;
+ my $over = (@_) ? shift : 0;
+ $w->GeometryRequest($w->screenwidth,$w->screenheight);
+ $w->overrideredirect($over);
+ $w->Post(0,0);
+}
 
+sub iconposition
+{
+ my $w = shift;
+ return $w->wm('iconposition',$1,$2) if (@_ == 1 && $_[0] =~ /^(\d+),(\d+)$/); 
+ $w->wm('iconposition',@_);
+}
